@@ -1,10 +1,10 @@
 package InfluxDB::Writer;
-use strict;
-use warnings;
-
-our $VERSION = '1.002';
 
 # ABSTRACT: Various tools to send lines to InfluxDB
+our $VERSION = '1.003'; # VERSION
+
+use strict;
+use warnings;
 
 __END__
 
@@ -18,7 +18,7 @@ InfluxDB::Writer - Various tools to send lines to InfluxDB
 
 =head1 VERSION
 
-version 1.002
+version 1.003
 
 =head1 DESCRIPTION
 
@@ -50,11 +50,11 @@ We use L<Measure::Everything::InfluxDB::
 
 =head1 AUTHOR
 
-Thomas Klausner <domm@cpan.org>
+Thomas Klausner <domm@plix.at>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Thomas Klausner.
+This software is copyright (c) 2015 - 2021 by Thomas Klausner.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
