@@ -1,6 +1,7 @@
 package InfluxDB::Writer::AuthHeaderRole;
 
 # ABSTRACT: Helper role
+our $VERSION = '1.003'; # VERSION
 
 use Moose::Role;
 use MIME::Base64 qw/encode_base64/;
@@ -40,15 +41,15 @@ InfluxDB::Writer::AuthHeaderRole - Helper role
 
 =head1 VERSION
 
-version 1.002
+version 1.003
 
 =head1 AUTHOR
 
-Thomas Klausner <domm@cpan.org>
+Thomas Klausner <domm@plix.at>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Thomas Klausner.
+This software is copyright (c) 2015 - 2021 by Thomas Klausner.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
