@@ -1,12 +1,12 @@
 package InfluxDB::Writer::CompactFiles;
+
+# ABSTRACT: Collect and compact files containing InfluxDB lines
+our $VERSION = '1.003'; # VERSION
+
 use strict;
 use warnings;
 use feature 'say';
 
-our $VERSION = '1.000';
-
-# ABSTRACT: Collect and compact files containing InfluxDB lines
-
 use Moose;
 use Carp qw(croak);
 use Log::Any qw($log);
@@ -92,15 +92,15 @@ InfluxDB::Writer::CompactFiles - Collect and compact files containing InfluxDB l
 
 =head1 VERSION
 
-version 1.002
+version 1.003
 
 =head1 AUTHOR
 
-Thomas Klausner <domm@cpan.org>
+Thomas Klausner <domm@plix.at>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Thomas Klausner.
+This software is copyright (c) 2015 - 2021 by Thomas Klausner.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
