@@ -1,11 +1,12 @@
 package InfluxDB::Writer::SendLines;
+
+# ABSTRACT: Send lines from a file to InfluxDB
+our $VERSION = '1.003'; # VERSION
+
 use strict;
 use warnings;
 use feature 'say';
 
-our $VERSION = '1.000';
-
-# ABSTRACT: Send lines from a file to InfluxDB
 
 use Moose;
 use Carp qw(croak);
@@ -134,15 +135,15 @@ InfluxDB::Writer::SendLines - Send lines from a file to InfluxDB
 
 =head1 VERSION
 
-version 1.002
+version 1.003
 
 =head1 AUTHOR
 
-Thomas Klausner <domm@cpan.org>
+Thomas Klausner <domm@plix.at>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Thomas Klausner.
+This software is copyright (c) 2015 - 2021 by Thomas Klausner.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
